@@ -1,11 +1,11 @@
 # App::hopen::AppUtil - utility routines used by App::hopen::App
 package App::hopen::AppUtil;
 use Data::Hopen qw(:default isMYH MYH);
-use strict;
+use strict; use warnings;
 use Data::Hopen::Base;
 use parent 'Exporter';
 
-our $VERSION = '0.000011';
+our $VERSION = '0.000012'; # TRIAL
 
 our (@EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 BEGIN {
