@@ -1,10 +1,10 @@
 # App::hopen::BuildSystemGlobals - global data for build-system use cases.
 package App::hopen::BuildSystemGlobals;
 use Data::Hopen;
-use strict;
+use strict; use warnings;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000011';
+our $VERSION = '0.000012'; # TRIAL
 
 use parent 'Exporter';
 our @EXPORT;
