@@ -1,11 +1,11 @@
 # App::hopen::G::AssetOp - parent class for operations used by a
 # generator to build an asset
 package App::hopen::G::AssetOp;
-use strict;
+use strict; use warnings;
 use Data::Hopen::Base;
 use Quote::Code;
 
-our $VERSION = '0.000011';
+our $VERSION = '0.000012'; # TRIAL
 
 use parent 'App::hopen::G::Cmd';
 # we use Class::Tiny below
