@@ -1,10 +1,10 @@
 # App::hopen::G::FilesCmd - Cmd that outputs a list of files.
 package App::hopen::G::FilesCmd;
 use Data::Hopen;
-use strict;
+use strict; use warnings;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000011';
+our $VERSION = '0.000012'; # TRIAL
 
 use parent 'App::hopen::G::Cmd';
 use Class::Tiny {
@@ -25,6 +25,13 @@ Data::Hopen::G::FilesCmd - Cmd that holds a list of files.
 
 Used by L<Data::Hopen::H/files>.
 
+=head1 ATTRIBUTES
+
+=head2 files
+
+The files that this Cmd outputs.  Intended to be L<App::hopen::Util::BasedPath>
+instances.
+
 =head1 FUNCTIONS
 
 =cut
