@@ -1,9 +1,9 @@
 # App::hopen::H - H:: namespace for use in hopen files
 package App::hopen::H;
-use strict;
+use strict; use warnings;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000011';
+our $VERSION = '0.000012'; # TRIAL
 
 use parent 'Exporter';
 use vars::i '@EXPORT' => [];
