@@ -1,11 +1,11 @@
 # App::hopen::Phase::Check - checking-phase operations
 package App::hopen::Phase::Check;
 use Data::Hopen;
-use strict;
+use strict; use warnings;
 use Data::Hopen::Base;
 use parent 'Exporter';
 
-our $VERSION = '0.000011';
+our $VERSION = '0.000012'; # TRIAL
 
 our (@EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 BEGIN {
