@@ -1,11 +1,11 @@
 # App::hopen::Phase::Gen - generation-phase operations
 package App::hopen::Phase::Gen;
 use Data::Hopen;
-use strict;
+use strict; use warnings;
 use Data::Hopen::Base;
 #use parent 'Exporter';
 
-our $VERSION = '0.000011';
+our $VERSION = '0.000012'; # TRIAL
 
 #use Class::Tiny ;#qw(TODO);
 
