@@ -1,10 +1,10 @@
 # App::hopen::T::Gnu - GNU toolset
 package App::hopen::T::Gnu;
 use Data::Hopen;
-use strict;
+use strict; use warnings;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000011';
+our $VERSION = '0.000012'; # TRIAL
 
 #use parent 'Data::Hopen::TODO';
 #use Class::Tiny qw(TODO);
