@@ -1,15 +1,10 @@
 # App::hopen::T::Gnu::C - support GNU toolset, C language
-# TODO RESUME HERE - put .o files in the dest dir
 package App::hopen::T::Gnu::C;
 use Data::Hopen;
-use strict;
+use strict; use warnings;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000011';
-
-use parent 'Exporter';
-
-use Class::Tiny qw(op files _cc);
+our $VERSION = '0.000012'; # TRIAL
 
 use App::hopen::BuildSystemGlobals;   # For $DestDir.
     # TODO make the dirs available to nodes through the context.
@@ -23,7 +18,6 @@ use Data::Hopen qw(getparameters);
 use Data::Hopen::G::GraphBuilder;
 use Data::Hopen::Util::Data qw(forward_opts);
 use Data::Hopen::Util::Filename;
-#use Deep::Hash::Utils qw(deepvalue);
 use File::Which ();
 use Path::Class;
 
@@ -141,7 +135,7 @@ sub _find_compiler {
     croak "Could not find a C compiler" unless $_CC;
 } #_find_compiler()
 
-BEGIN { _find_compiler; }
+BEGIN { _find_compiler if eval '$App::hopen::RUNNING'; }
 
 1;
 __END__
