@@ -1,10 +1,10 @@
 # App::hopen::Tool - base class for a hopen tool.  DEPRECATED.
 package App::hopen::Tool;
 #use Data::Hopen;
-use strict;
+use strict; use warnings;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000011';
+our $VERSION = '0.000012'; # TRIAL
 
 use parent 'App::hopen::G::Cmd';
 #use Class::Tiny;
