@@ -1,9 +1,9 @@
 # App::hopen::Util::BasedPath - A path relative to a specified base
 package App::hopen::Util::BasedPath;
-use strict;
+use strict; use warnings;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000011';
+our $VERSION = '0.000012'; # TRIAL
 
 use Exporter qw(import);
 our @EXPORT; BEGIN { @EXPORT = qw(based_path); }
