@@ -8,7 +8,7 @@ use Import::Into;
 # Pragmas
 use 5.014;
 use feature ":5.14";
-use strict;
+use strict; use warnings;
 use warnings;
 
 # Packages
@@ -20,7 +20,7 @@ use Carp;
 use Test::More;
 #use Text::ParseWords qw(shellwords);
 
-use strict;
+use strict; use warnings;
 use Data::Hopen::Base;
 
 BEGIN { $Data::Dumper::Indent = 1; }    # For easier-to-read dumps
